@@ -22,16 +22,13 @@ from torch.nn import functional as F
 from torch.utils.data import random_split
 
 import pytorch_lightning as pl
-from pl_examples import _DALI_AVAILABLE, _DATASETS_PATH, _TORCHVISION_MNIST_AVAILABLE, cli_lightning_logo
+from pl_examples import _DALI_AVAILABLE, _DATASETS_PATH, cli_lightning_logo
+from pl_examples.basic_examples.mnist_datamodule import MNIST
 from pytorch_lightning.utilities.cli import LightningCLI
 from pytorch_lightning.utilities.imports import _TORCHVISION_AVAILABLE
 
 if _TORCHVISION_AVAILABLE:
     from torchvision import transforms
-if _TORCHVISION_MNIST_AVAILABLE:
-    from torchvision.datasets import MNIST
-else:
-    from tests.helpers.datasets import MNIST
 
 if _DALI_AVAILABLE:
     from nvidia.dali import __version__ as dali_version
@@ -39,15 +36,15 @@ if _DALI_AVAILABLE:
     from nvidia.dali.pipeline import Pipeline
     from nvidia.dali.plugin.pytorch import DALIClassificationIterator
 
-    NEW_DALI_API = Version(dali_version) >= Version('0.28.0')
+    NEW_DALI_API = Version(dali_version) >= Version("0.28.0")
     if NEW_DALI_API:
         from nvidia.dali.plugin.base_iterator import LastBatchPolicy
 else:
-    warn('NVIDIA DALI is not available')
+    warn("NVIDIA DALI is not available")
     ops, Pipeline, DALIClassificationIterator, LastBatchPolicy = ..., ABC, ABC, ABC
 
 
-class ExternalMNISTInputIterator(object):
+class ExternalMNISTInputIterator:
     """
     This iterator class wraps torchvision's MNIST dataset and returns the images and labels in batches
     """
@@ -81,7 +78,7 @@ class ExternalSourcePipeline(Pipeline):
     """
 
     def __init__(self, batch_size, eii, num_threads, device_id):
-        super(ExternalSourcePipeline, self).__init__(batch_size, num_threads, device_id, seed=12)
+        super().__init__(batch_size, num_threads, device_id, seed=12)
         self.source = ops.ExternalSource(source=eii, num_outputs=2)
         self.build()
 
@@ -115,7 +112,7 @@ class DALIClassificationLoader(DALIClassificationIterator):
                 auto_reset,
                 dynamic_shape,
                 last_batch_policy=last_batch_policy,
-                last_batch_padded=last_batch_padded
+                last_batch_padded=last_batch_padded,
             )
         else:
             super().__init__(
@@ -130,12 +127,7 @@ class DALIClassificationLoader(DALIClassificationIterator):
 
 
 class LitClassifier(pl.LightningModule):
-
-    def __init__(
-        self,
-        hidden_dim: int = 128,
-        learning_rate: float = 0.0001,
-    ):
+    def __init__(self, hidden_dim: int = 128, learning_rate: float = 0.0001):
         super().__init__()
         self.save_hyperparameters()
 
@@ -161,24 +153,20 @@ class LitClassifier(pl.LightningModule):
         x, y = self.split_batch(batch)
         y_hat = self(x)
         loss = F.cross_entropy(y_hat, y)
-        self.log('valid_loss', loss)
+        self.log("valid_loss", loss)
 
     def test_step(self, batch, batch_idx):
         x, y = self.split_batch(batch)
         y_hat = self(x)
         loss = F.cross_entropy(y_hat, y)
-        self.log('test_loss', loss)
+        self.log("test_loss", loss)
 
     def configure_optimizers(self):
         return torch.optim.Adam(self.parameters(), lr=self.hparams.learning_rate)
 
 
 class MyDataModule(pl.LightningDataModule):
-
-    def __init__(
-        self,
-        batch_size: int = 32,
-    ):
+    def __init__(self, batch_size: int = 32):
         super().__init__()
         dataset = MNIST(_DATASETS_PATH, train=True, download=True, transform=transforms.ToTensor())
         self.mnist_test = MNIST(_DATASETS_PATH, train=False, download=True, transform=transforms.ToTensor())
@@ -194,26 +182,15 @@ class MyDataModule(pl.LightningDataModule):
 
     def train_dataloader(self):
         return DALIClassificationLoader(
-            self.pipe_train,
-            size=len(self.mnist_train),
-            auto_reset=True,
-            fill_last_batch=True,
+            self.pipe_train, size=len(self.mnist_train), auto_reset=True, fill_last_batch=True
         )
 
     def val_dataloader(self):
-        return DALIClassificationLoader(
-            self.pipe_val,
-            size=len(self.mnist_val),
-            auto_reset=True,
-            fill_last_batch=False,
-        )
+        return DALIClassificationLoader(self.pipe_val, size=len(self.mnist_val), auto_reset=True, fill_last_batch=False)
 
     def test_dataloader(self):
         return DALIClassificationLoader(
-            self.pipe_test,
-            size=len(self.mnist_test),
-            auto_reset=True,
-            fill_last_batch=False,
+            self.pipe_test, size=len(self.mnist_test), auto_reset=True, fill_last_batch=False
         )
 
 
@@ -221,9 +198,8 @@ def cli_main():
     if not _DALI_AVAILABLE:
         return
 
-    cli = LightningCLI(LitClassifier, MyDataModule, seed_everything_default=1234)
-    result = cli.trainer.test(cli.model, datamodule=cli.datamodule)
-    print(result)
+    cli = LightningCLI(LitClassifier, MyDataModule, seed_everything_default=1234, save_config_overwrite=True)
+    cli.trainer.test(cli.model, datamodule=cli.datamodule)
 
 
 if __name__ == "__main__":
