@@ -39,10 +39,10 @@ def _create_synth_kitti_dataset(path_dir: str, image_dims: tuple = (1024, 512)):
     for p_dir in (path_dir_images, path_dir_masks):
         os.makedirs(p_dir, exist_ok=True)
     for i in range(3):
-        path_img = os.path.join(path_dir_images, f'dummy_kitti_{i}.png')
-        Image.new('RGB', image_dims).save(path_img)
-        path_mask = os.path.join(path_dir_masks, f'dummy_kitti_{i}.png')
-        Image.new('L', image_dims).save(path_mask)
+        path_img = os.path.join(path_dir_images, f"dummy_kitti_{i}.png")
+        Image.new("RGB", image_dims).save(path_img)
+        path_mask = os.path.join(path_dir_masks, f"dummy_kitti_{i}.png")
+        Image.new("L", image_dims).save(path_mask)
 
 
 class KITTI(Dataset):
@@ -73,8 +73,9 @@ class KITTI(Dataset):
     >>> KITTI(dataset_path, 'train')  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
     <...semantic_segmentation.KITTI object at ...>
     """
-    IMAGE_PATH = os.path.join('training', 'image_2')
-    MASK_PATH = os.path.join('training', 'semantic')
+
+    IMAGE_PATH = os.path.join("training", "image_2")
+    MASK_PATH = os.path.join("training", "semantic")
 
     def __init__(
         self,
@@ -83,7 +84,7 @@ class KITTI(Dataset):
         img_size: tuple = (1242, 376),
         void_labels: list = DEFAULT_VOID_LABELS,
         valid_labels: list = DEFAULT_VALID_LABELS,
-        transform=None
+        transform=None,
     ):
         self.img_size = img_size
         self.void_labels = void_labels
@@ -103,7 +104,7 @@ class KITTI(Dataset):
         random_inst = random.Random(12345)  # for repeatability
         n_items = len(self.img_list)
         idxs = random_inst.sample(range(n_items), n_items // 5)
-        if self.split == 'train':
+        if self.split == "train":
             idxs = [idx for idx in range(n_items) if idx not in idxs]
         self.img_list = [self.img_list[i] for i in idxs]
         self.mask_list = [self.mask_list[i] for i in idxs]
@@ -116,7 +117,7 @@ class KITTI(Dataset):
         img = img.resize(self.img_size)
         img = np.array(img)
 
-        mask = Image.open(self.mask_list[idx]).convert('L')
+        mask = Image.open(self.mask_list[idx]).convert("L")
         mask = mask.resize(self.img_size)
         mask = np.array(mask)
         mask = self.encode_segmap(mask)
@@ -142,7 +143,7 @@ class KITTI(Dataset):
         """
         Returns a list of absolute paths to images inside given `path`
         """
-        files_list = list()
+        files_list = []
         for filename in os.listdir(path):
             files_list.append(os.path.join(path, filename))
         return files_list
@@ -200,12 +201,16 @@ class SegModel(pl.LightningModule):
         self.net = UNet(
             num_classes=19, num_layers=self.num_layers, features_start=self.features_start, bilinear=self.bilinear
         )
-        self.transform = transforms.Compose([
-            transforms.ToTensor(),
-            transforms.Normalize(mean=[0.35675976, 0.37380189, 0.3764753], std=[0.32064945, 0.32098866, 0.32325324])
-        ])
-        self.trainset = KITTI(self.data_path, split='train', transform=self.transform)
-        self.validset = KITTI(self.data_path, split='valid', transform=self.transform)
+        self.transform = transforms.Compose(
+            [
+                transforms.ToTensor(),
+                transforms.Normalize(
+                    mean=[0.35675976, 0.37380189, 0.3764753], std=[0.32064945, 0.32098866, 0.32325324]
+                ),
+            ]
+        )
+        self.trainset = KITTI(self.data_path, split="train", transform=self.transform)
+        self.validset = KITTI(self.data_path, split="valid", transform=self.transform)
 
     def forward(self, x):
         return self.net(x)
@@ -215,9 +220,9 @@ class SegModel(pl.LightningModule):
         img = img.float()
         mask = mask.long()
         out = self(img)
-        loss_val = F.cross_entropy(out, mask, ignore_index=250)
-        log_dict = {'train_loss': loss_val}
-        return {'loss': loss_val, 'log': log_dict, 'progress_bar': log_dict}
+        loss = F.cross_entropy(out, mask, ignore_index=250)
+        log_dict = {"train_loss": loss}
+        return {"loss": loss, "log": log_dict, "progress_bar": log_dict}
 
     def validation_step(self, batch, batch_idx):
         img, mask = batch
@@ -225,12 +230,12 @@ class SegModel(pl.LightningModule):
         mask = mask.long()
         out = self(img)
         loss_val = F.cross_entropy(out, mask, ignore_index=250)
-        return {'val_loss': loss_val}
+        return {"val_loss": loss_val}
 
     def validation_epoch_end(self, outputs):
-        loss_val = torch.stack([x['val_loss'] for x in outputs]).mean()
-        log_dict = {'val_loss': loss_val}
-        return {'log': log_dict, 'val_loss': log_dict['val_loss'], 'progress_bar': log_dict}
+        loss_val = torch.stack([x["val_loss"] for x in outputs]).mean()
+        log_dict = {"val_loss": loss_val}
+        return {"log": log_dict, "val_loss": log_dict["val_loss"], "progress_bar": log_dict}
 
     def configure_optimizers(self):
         opt = torch.optim.Adam(self.net.parameters(), lr=self.learning_rate)
@@ -245,19 +250,16 @@ class SegModel(pl.LightningModule):
 
     @staticmethod
     def add_model_specific_args(parent_parser):  # pragma: no-cover
-        parser = ArgumentParser(parents=[parent_parser])
+        parser = parent_parser.add_argument_group("SegModel")
         parser.add_argument("--data_path", type=str, help="path where dataset is stored")
         parser.add_argument("--batch_size", type=int, default=16, help="size of the batches")
         parser.add_argument("--lr", type=float, default=0.001, help="adam: learning rate")
         parser.add_argument("--num_layers", type=int, default=5, help="number of layers on u-net")
         parser.add_argument("--features_start", type=float, default=64, help="number of features in first layer")
         parser.add_argument(
-            "--bilinear",
-            action='store_true',
-            default=False,
-            help="whether to use bilinear interpolation or transposed"
+            "--bilinear", action="store_true", default=False, help="whether to use bilinear interpolation or transposed"
         )
-        return parser
+        return parent_parser
 
 
 def main(hparams: Namespace):
@@ -287,7 +289,7 @@ def main(hparams: Namespace):
     trainer.fit(model)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli_lightning_logo()
     parser = ArgumentParser(add_help=False)
     parser = SegModel.add_model_specific_args(parser)
