@@ -15,7 +15,4 @@
 from pytorch_lightning.core.datamodule import LightningDataModule
 from pytorch_lightning.core.lightning import LightningModule
 
-__all__ = [
-    'LightningDataModule',
-    'LightningModule',
-]
+__all__ = ["LightningDataModule", "LightningModule"]
