@@ -15,11 +15,10 @@ from typing import Any, Optional
 
 from torchmetrics import AveragePrecision as _AveragePrecision
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
 class AveragePrecision(_AveragePrecision):
-
     @deprecated_metrics(target=_AveragePrecision)
     def __init__(
         self,
@@ -35,4 +34,4 @@ class AveragePrecision(_AveragePrecision):
         .. deprecated::
             Use :class:`~torchmetrics.AveragePrecision`. Will be removed in v1.5.0.
         """
-        _ = num_classes, pos_label, compute_on_step, dist_sync_on_step, process_group
+        void(num_classes, pos_label, compute_on_step, dist_sync_on_step, process_group)
