@@ -15,7 +15,7 @@
 import torch
 from torchmetrics.functional import mean_squared_error as _mean_squared_error
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
 @deprecated_metrics(target=_mean_squared_error)
@@ -24,3 +24,4 @@ def mean_squared_error(preds: torch.Tensor, target: torch.Tensor) -> torch.Tenso
     .. deprecated::
         Use :func:`torchmetrics.functional.mean_squared_error`. Will be removed in v1.5.0.
     """
+    return void(preds, target)
