@@ -18,10 +18,10 @@ from torchmetrics.functional import precision as _precision
 from torchmetrics.functional import precision_recall as _precision_recall
 from torchmetrics.functional import recall as _recall
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
-@deprecated_metrics(target=_precision)
+@deprecated_metrics(target=_precision, args_mapping={"is_multiclass": None})
 def precision(
     preds: torch.Tensor,
     target: torch.Tensor,
@@ -37,9 +37,10 @@ def precision(
     .. deprecated::
         Use :func:`torchmetrics.functional.precision`. Will be removed in v1.5.0.
     """
+    return void(preds, target, average, mdmc_average, ignore_index, num_classes, threshold, top_k, is_multiclass)
 
 
-@deprecated_metrics(target=_recall)
+@deprecated_metrics(target=_recall, args_mapping={"is_multiclass": None})
 def recall(
     preds: torch.Tensor,
     target: torch.Tensor,
@@ -55,9 +56,10 @@ def recall(
     .. deprecated::
         Use :func:`torchmetrics.functional.accuracy`. Will be removed in v1.5.0.
     """
+    return void(preds, target, average, mdmc_average, ignore_index, num_classes, threshold, top_k, is_multiclass)
 
 
-@deprecated_metrics(target=_precision_recall)
+@deprecated_metrics(target=_precision_recall, args_mapping={"is_multiclass": None})
 def precision_recall(
     preds: torch.Tensor,
     target: torch.Tensor,
@@ -73,3 +75,4 @@ def precision_recall(
     .. deprecated::
         Use :func:`torchmetrics.functional.precision_recall`. Will be removed in v1.5.0.
     """
+    return void(preds, target, average, mdmc_average, ignore_index, num_classes, threshold, top_k, is_multiclass)
