@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import math
 from typing import Any, Callable, List, Optional, Tuple, Union
 
 import torch
@@ -20,18 +19,19 @@ from torch.nn import Module
 from torch.optim import Optimizer
 
 import pytorch_lightning as pl
+from pytorch_lightning.core.hooks import CheckpointHooks
 from pytorch_lightning.plugins.base_plugin import Plugin
 from pytorch_lightning.utilities import GradClipAlgorithmType
 from pytorch_lightning.utilities.types import _PARAMETERS
 
 
-class PrecisionPlugin(Plugin):
+class PrecisionPlugin(Plugin, CheckpointHooks):
     """
     Base class for all plugins handling the precision-specific parts of the training.
-    The static classattributes EPSILON and precision must be overwritten in child-classes and their
-    default values reflect fp32 training.
+    The class attribute precision must be overwritten in child classes.
+    The default value reflects fp32 training.
     """
-    EPSILON: float = 1e-6
+
     precision: Union[str, int] = 32
 
     def master_params(self, optimizer: Optimizer) -> _PARAMETERS:
@@ -40,60 +40,67 @@ class PrecisionPlugin(Plugin):
         Maybe different in other precision plugins.
         """
         for group in optimizer.param_groups:
-            for p in group["params"]:
-                yield p
+            yield from group["params"]
 
     def connect(
-        self,
-        model: Module,
-        optimizers: List[Optimizer],
-        lr_schedulers: List[Any],
+        self, model: Module, optimizers: List[Optimizer], lr_schedulers: List[Any]
     ) -> Tuple[Module, List[Optimizer], List[Any]]:
         """Connects this plugin to the accelerator and the training process"""
         return model, optimizers, lr_schedulers
 
-    def backward(
-        self,
-        model: 'pl.LightningModule',
-        closure_loss: Tensor,
-        optimizer: Optimizer,
-        opt_idx: int,
-        should_accumulate: bool,
-        *args: Any,
-        **kwargs: Any,
-    ) -> Tensor:
-        """performs the actual backpropagation
+    def pre_backward(self, model: "pl.LightningModule", closure_loss: Tensor) -> Tensor:
+        """Run before precision plugin executes backward
 
         Args:
             model: the model to be optimized
             closure_loss: the loss value obtained from the closure
-            optimizer: the optimizer to perform the step lateron
-            opt_idx: the optimizer's index
-            should_accumulate: whether to accumulate gradients or not
-
         """
-        automatic_optimization = model.automatic_optimization
+        model.trainer.call_hook("on_before_backward", closure_loss)
+        return closure_loss
 
+    def backward(
+        self,
+        model: "pl.LightningModule",
+        closure_loss: Tensor,
+        optimizer: Optional[Optimizer],
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
+        """Performs the actual backpropagation
+
+        Args:
+            model: the model to be optimized
+            closure_loss: the loss value obtained from the closure
+            optimizer: current optimizer being used. ``None`` if using manual optimization
+        """
         # do backward pass
-        if automatic_optimization:
-            model.backward(closure_loss, optimizer, opt_idx)
+        if model is not None and isinstance(model, pl.LightningModule):
+            model.backward(closure_loss, optimizer, *args, **kwargs)
         else:
             closure_loss.backward(*args, **kwargs)
 
+    def post_backward(self, model: "pl.LightningModule", closure_loss: Tensor) -> Tensor:
+        """Run after precision plugin executes backward
+
+        Args:
+            model: the model to be optimized
+            closure_loss: the loss value obtained from the closure
+        """
         # once backward has been applied, release graph
         closure_loss = closure_loss.detach()
-
+        model.trainer.call_hook("on_after_backward")
         return closure_loss
 
     def pre_optimizer_step(
         self,
-        pl_module: 'pl.LightningModule',
+        model: "pl.LightningModule",
         optimizer: Optimizer,
         optimizer_idx: int,
         lambda_closure: Callable,
         **kwargs: Any,
     ) -> bool:
         """Hook to do something before each optimizer step."""
+        model.trainer.call_hook("on_before_optimizer_step", optimizer, optimizer_idx)
         return True
 
     def post_optimizer_step(self, optimizer: Optimizer, optimizer_idx: int) -> None:
@@ -104,7 +111,7 @@ class PrecisionPlugin(Plugin):
         optimizer: Optimizer,
         clip_val: Union[int, float],
         gradient_clip_algorithm: GradClipAlgorithmType = GradClipAlgorithmType.NORM,
-        model: Optional[Module] = None
+        model: Optional[Module] = None,
     ) -> None:
         """Clips the gradients"""
         if clip_val is None:
@@ -118,32 +125,14 @@ class PrecisionPlugin(Plugin):
             self.clip_grad_by_value(optimizer, clip_val)
         elif gradient_clip_algorithm == GradClipAlgorithmType.NORM:
             # TODO: there should be a mechanism to set `norm_type`
-            self.clip_grad_by_norm(optimizer, clip_val, eps=self.EPSILON)
+            self.clip_grad_by_norm(optimizer, clip_val)
 
     def clip_grad_by_value(self, optimizer: Optimizer, clip_val: Union[int, float]) -> None:
         """Clip gradients by value"""
         parameters = self.master_params(optimizer)
         torch.nn.utils.clip_grad_value_(parameters, clip_value=clip_val)
 
-    def clip_grad_by_norm(
-        self, optimizer: Optimizer, clip_val: Union[int, float], norm_type: float = 2.0, eps: float = 1e-6
-    ) -> None:
+    def clip_grad_by_norm(self, optimizer: Optimizer, clip_val: Union[int, float]) -> None:
         """Clip gradients by norm"""
         parameters = self.master_params(optimizer)
-
-        # TODO: replace this with torch.nn.clip_grad_norm_
-        parameters = list(filter(lambda p: p.grad is not None, parameters))
-        device = parameters[0].device
-
-        if norm_type == math.inf:
-            total_norm = max(p.grad.data.abs().max() for p in parameters)
-        else:
-            out = torch.empty(len(parameters), device=device)
-            for i, p in enumerate(parameters):
-                torch.norm(p.grad.data.to(device), norm_type, out=out[i])
-            total_norm = torch.norm(out, norm_type)
-
-        clip_coef = torch.tensor(clip_val, device=device) / (total_norm + eps)
-        clip_coef = torch.min(clip_coef, torch.ones_like(clip_coef))
-        for p in parameters:
-            p.grad.data.mul_(clip_coef.to(p.grad.data.device))
+        torch.nn.utils.clip_grad_norm_(parameters, clip_val)
