@@ -34,7 +34,7 @@ def seed_everything(seed: Optional[int] = None, workers: bool = False) -> int:
     In addition, sets the following environment variables:
 
     - `PL_GLOBAL_SEED`: will be passed to spawned subprocesses (e.g. ddp_spawn backend).
-    - `PL_SEED_WORKERS`: (optional) is set to 1 if ```workers=True``.
+    - `PL_SEED_WORKERS`: (optional) is set to 1 if ``workers=True``.
 
     Args:
         seed: the integer value seed for global random state in Lightning.
@@ -102,7 +102,7 @@ def pl_worker_init_function(worker_id: int, rank: Optional = None) -> None:  # p
     # back out the base seed so we can use all the bits
     base_seed = process_seed - worker_id
     log.debug(
-        f'Initializing random number generators of process {global_rank} worker {worker_id} with base seed {base_seed}'
+        f"Initializing random number generators of process {global_rank} worker {worker_id} with base seed {base_seed}"
     )
     ss = np.random.SeedSequence([base_seed, worker_id, global_rank])
     # use 128 bits (4 x 32-bit words)
